#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1.2
visibility:           public
id:                   citeproc-0.8.1.2-hVyUkRzRuUCRPUhYqYN43
key:                  citeproc-0.8.1.2-hVyUkRzRuUCRPUhYqYN43
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  e2b144785b1e5f1edb728cae3f9690a1
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1.2-hVyUkRzRuUCRPUhYqYN43
depends:
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4
    attoparsec-0.14.4-DVQW3zaPrEjFLUvmkAZYCq base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    pandoc-types-1.23.1.1-KgMp7ipiwIdDM3OUvlIQe6
    safe-0.3.21-CNekTOvlOCxBWhpb53aZQe
    scientific-0.3.8.1-8GGUGhnyv3iL0QkuRDa0Ak text-2.0.2
    text-icu-0.8.0.5-KhkUMCRkzzZ3gmUkAzmR8Y transformers-0.6.1.0
    unicode-collation-0.1.3.7-BV6GaNUGMpx873PGYVsek0
    uniplate-1.6.13-AzjlWyYh2ZSH2gzxES4aea
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    xml-conduit-1.9.1.4-79wpp9gzyJhK2JPOyA1vwv

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

